<?php

defined( 'PRESSO_CONST_REDUX_ASSET_URL' ) || define( 'PRESSO_CONST_REDUX_ASSET_URL', get_template_directory_uri() . '/images/admin' );

/* -----------------------------------------------------------------------------
 * Load Theme Options Panel
 * -------------------------------------------------------------------------- */

if ( function_exists( 'presso_load_theme_options_panel' ) ) {
	// Load theme option panel from plugin
	presso_load_theme_options_panel();

} else if ( ! class_exists( 'ReduxFramework' ) ) {
	// Use a default options when theme options panel plugin is not loaded
	require_once get_template_directory().'/inc/options-default.php';
}


/* -----------------------------------------------------------------------------
 * Remove Redux Demo Mode & Notices
 * -------------------------------------------------------------------------- */
add_action( 'init', 'presso_remove_redux_demo_mode_link' );
if ( ! function_exists( 'presso_remove_redux_demo_mode_link' ) ) {
	function presso_remove_redux_demo_mode_link() {
		if ( class_exists('ReduxFrameworkPlugin') ) {
			remove_filter( 'plugin_row_meta', array( ReduxFrameworkPlugin::get_instance(), 'plugin_metalinks'), null, 2 );
		}

		if ( class_exists('ReduxFrameworkPlugin') ) {
			remove_action('admin_notices', array( ReduxFrameworkPlugin::get_instance(), 'admin_notices' ) );    
		}
	}
}


/* -----------------------------------------------------------------------------
 * Theme Option Proxy
 * -------------------------------------------------------------------------- */
if ( ! function_exists( 'presso_get_theme_option' ) ) {
	function presso_get_theme_option( $opt_name, $default = null ) {
		global $presso_options;
		if ( isset( $presso_options[ $opt_name ] ) ) return $presso_options[ $opt_name ];
		else return $default;
	}
}

/* -----------------------------------------------------------------------------
 * Prepare Options
 * -------------------------------------------------------------------------- */
$theme = wp_get_theme();
$vw_opt_name = 'presso_options';

$help_html = '<a href="https://envirra.com/themes/presso3/document/" target="_blank"><img src="'.get_template_directory_uri().'/images/admin/help-documentation.png"></a>';
$help_html .= '<a href="https://envirra.com/themes/presso3/document/#troubleshooting" target="_blank"><img src="'.get_template_directory_uri().'/images/admin/help-troubleshooting.png"></a>';
$help_html .= '<a href="https://themeforest.net/user/envirra/portfolio?ref=envirra" target="_blank"><img src="'.get_template_directory_uri().'/images/admin/help-more-themes.png"></a>';

$args = array(
	// TYPICAL -> Change these values as you need/desire
	'opt_name' => $vw_opt_name,
	// This is where your data is stored in the database and also becomes your global variable name.
	'display_name' => $theme->get( 'Name' ),
	// Name that appears at the top of your panel
	// 'display_version' => $theme->get( 'Version' ),
	// Version that appears at the top of your panel
	'menu_type' => 'menu',
	//Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
	'allow_sub_menu' => true,
	// Show the sections below the admin menu item or not
	'menu_title' => 'Theme Options',
	'page_title' => 'Theme Options',
	// You will need to generate a Google API key to use this feature.
	// Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
	'google_api_key' => '',
	// Set it you want google fonts to update weekly. A google_api_key value is required.
	'google_update_weekly' => false,
	// Must be defined to add google fonts to the typography module
	'async_typography' => false,
	// Use a asynchronous font on the front end or font string
	//'disable_google_fonts_link' => true, // Disable this in case you want to create your own google fonts loader
	'admin_bar' => true,
	// Show the panel pages on the admin bar
	'admin_bar_icon' => 'dashicons-portfolio',
	// Choose an icon for the admin bar menu
	'admin_bar_priority' => 50,
	// Choose an priority for the admin bar menu
	'global_variable' => '',
	// Set a different name for your global variable other than the opt_name
	'dev_mode' => false,
	// Show the time the page took to load, etc
	'update_notice' => false,
	// If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
	'customizer' => true,
	// Enable basic customizer support
	//'open_expanded' => true, // Allow you to start the panel in an expanded way initially.
	//'disable_save_warn' => true, // Disable the save warning when a user changes a field

	// OPTIONAL -> Give you extra features
	'page_priority' => null,
	// Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
	'page_parent' => 'themes.php',
	// For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
	'page_permissions' => 'manage_options',
	// Permissions needed to access the options panel.
	'menu_icon' => '',
	// Specify a custom URL to an icon
	'last_tab' => '',
	// Force your panel to always open to a specific tab (by id)
	'page_icon' => 'icon-themes',
	// Icon displayed in the admin panel next to your menu_title
	'page_slug' => 'presso_theme_options',
	// Page slug used to denote the panel
	'save_defaults' => true,
	// On load save the defaults to DB before user clicks save or not
	'default_show' => false,
	// If true, shows the default value next to each field that is not the default value.
	'default_mark' => '',
	// What to print by the field's title if the value shown is default. Suggested: *
	'show_import_export' => true,
	// Shows the Import/Export panel when not used as a field.

	// CAREFUL -> These options are for advanced use only
	'transient_time' => 60 * MINUTE_IN_SECONDS,
	'output' => true,
	// Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
	'output_tag' => true,
	// Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
	// 'footer_credit' => '', // Disable the footer credit of Redux. Please leave if you can help it.

	// FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
	'database' => '',
	// possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
	'system_info' => false,
	// REMOVE

	//'compiler' => true,

	// HINTS
	'hints' => array(
		'icon' => 'el el-question-sign',
		'icon_position' => 'right',
		'icon_color' => 'lightgray',
		'icon_size' => 'normal',
		'tip_style' => array(
			'color' => 'light',
			'shadow' => true,
			'rounded' => false,
			'style' => '',
		),
		'tip_position' => array(
			'my' => 'top left',
			'at' => 'bottom right',
		),
		'tip_effect' => array(
			'show' => array(
				'effect' => 'slide',
				'duration' => '500',
				'event' => 'mouseover',
			),
			'hide' => array(
				'effect' => 'slide',
				'duration' => '500',
				'event' => 'click mouseleave',
			),
		),
	)
);

if ( ! class_exists( 'Redux' ) ) return;

Redux::setArgs( $vw_opt_name, $args );





/**
General
 */

Redux::setSection( $vw_opt_name, array(
	'title' => esc_html__( 'General', 'presso' ),
	'id' => 'presso-options-general',
	'desc' => '',
	'icon' => 'el el-website',
	'fields' => array(
		array(
			'id'=>'theme_info_1',
			'type' => 'raw', 
			'content' => $help_html,
		),

		array(
			'id'=>'site_layout',
			'type' => 'select',
			'title' => esc_html__( 'Site Layout', 'presso' ), 
			'options' => array(
				'full-width' => esc_html__( 'Full-Width', 'presso' ),
				'boxed' => esc_html__( 'Boxed', 'presso' ),
				'frame' => esc_html__( 'Frame', 'presso' ),
			),
			'default' => 'full-width',
		),

		array(
			'id'=>'mobile_sidebar',
			'type' => 'select',
			'title' => esc_html__( 'Mobile Sidebar', 'presso' ), 
			'subtitle' => esc_html__( 'Select a sidebar to be shown in mobile menu', 'presso' ),
			'data' => 'sidebar',
			'default' => 'mobile-sidebar',
		),

		array(
			'id'=>'enable_sticky_menu',
			'type' => 'switch', 
			'title' => esc_html__( 'Enable Sticky Menu', 'presso' ),
			'subtitle' => esc_html__( 'The element will be sticky when scrolling up', 'presso' ),
			'default' => 1,
		),

		array(
			'id'=>'enable_sticky_sidebar',
			'type' => 'switch', 
			'title' => esc_html__( 'Enable Sticky Sidebar', 'presso' ),
			'subtitle' => esc_html__( 'Sidebars will be sticky when scrolling through a long content', 'presso' ),
			'default' => 1,
		),
		
		array(
			'id'=>'enable_open_graph',
			'type' => 'switch', 
			'title' => esc_html__( 'Enable Facebook Open Graph Support', 'presso' ),
			'default' => 1,
		),

		array(
			'id'=>'enable_fly_in_effect',
			'type' => 'switch', 
			'title' => esc_html__( 'Enable Fly-In Effect', 'presso' ),
			'default' => 1,
		),

		array(
			'id'=>'enable_smooth_scroll',
			'type' => 'switch', 
			'title' => esc_html__( 'Enable Smooth Scroll', 'presso' ),
			'default' => 1,
		),

		array(
			'id' => 'enable_custom_gallery',
			'type' => 'switch',
			'title' => esc_html__( 'Enable Custom Gallery', 'presso' ),
			'subtitle' => esc_html__( 'Turn it off if you need to use the Jetpack Carousel or other gallery plugins', 'presso' ),
			'default' => '1' // 1 = checked | 0 = unchecked
		),

		array(
			'id'=>'avoid_duplicate_post',
			'type' => 'switch', 
			'title' => esc_html__( 'Avoid Duplicate Posts', 'presso' ),
			'subtitle'=> esc_html__( 'Turn on this option to a duplicate posts in the page composer and some elements', 'presso' ),
			'default' => 0,
		),

		array(
			'id'=>'enable_cdnjs',
			'type' => 'switch', 
			'title' => esc_html__( 'Enable CDNJS Support', 'presso' ),
			'subtitle' => esc_html__( "Load JS files from CDNJS for better performance. (Advanced user only)", 'presso' ),
			'default' => 0,
		),
	),
) );


Redux::setSection( $vw_opt_name, array(
	'title' => esc_html__( 'Sidebars', 'presso' ),
	'desc' => '',
	'id' => 'presso-options-sidebars',
	'subsection' => true,
	'fields' => array(
		array(
			'id'=>'additional_sidebars',
			'type' => 'multi_text', 
			'title' => esc_html__( 'Additional Sidebars', 'presso' ),
			'subtitle' => esc_html__( 'Add an additional sidebars here', 'presso' ),
			'desc' => wp_kses_post( __( '<i>Only <code>A-Z</code>, <code>a-z</code>, <code>_</code> and <code>0123456789</code> allowed</i>', 'presso' ) ),
			'show_empty' => false,
			'validate' => 'preg_replace',
			'preg' => array(
				'pattern' => '/[^0-9a-zA-Z_]/s', 
				'replacement' => '_',
			),
		),
	),
) );


Redux::setSection( $vw_opt_name, array(
	'title' => esc_html__( 'Color', 'presso' ),
	'desc' => '',
	'id' => 'presso-options-site-background-color',
	'subsection' => true,
	'fields' => array(
		array(
			'id'=>'accent_color',
			'type' => 'color', 
			'title' => esc_html__( 'Accent Color', 'presso' ),
			'subtitle' => esc_html__( 'An accent color for site', 'presso' ),
			'transparent' => false,
			'default' => '#3facd6',
		),

		array(
			'id'=>'site_background',
			'type' => 'background', 
			'title' => esc_html__( 'Site Background', 'presso' ),
			'subtitle' => wp_kses_post( __( 'Upload background image to be a site background (only visible when Site Layout is set to <strong>Boxed</strong>).', 'presso' ) ),
			'output' => array( 'body' ),
		),

		array(
			'id'=>'content_background_color',
			'type' => 'color', 
			'title' => esc_html__( 'Content Background Color', 'presso' ),
			'subtitle' => esc_html__( 'A background color for content area', 'presso' ),
			'transparent' => false,
			'default' => '#fff',
			'output' => array( 'background-color' => '.vw-content-area' )
		),

		array(
			'id'=>'widget_separator',
			'type' => 'border', 
			'title' => esc_html__( 'Widget Separator','presso' ),
			'subtitle'=> 'A style of widget separator',
			'all' => false,
			'top' => true,
			'bottom' => false,
			'left' => false,
			'right' => false,
			'style' => false,
			'default' => array(
				'border-color' => '#333',
				'border-top' => '6px', 
			),
		),

		array(
			'id'=>'section_separator',
			'type' => 'border', 
			'title' => esc_html__( 'Section Separator','presso' ),
			'subtitle'=> 'A style of section separator',
			'all' => false,
			'top' => true,
			'bottom' => false,
			'left' => false,
			'right' => false,
			'style' => false,
			'default' => array(
				'border-color' => '#333',
				'border-top' => '6px', 
			),
		),
	),
) );

Redux::setSection( $vw_opt_name, array(
	'title' => esc_html__( 'Site Social Networks', 'presso' ),
	'desc' => esc_html__( "These are options for setting up the site's social network profiles.", 'presso' ),
	'id' => 'presso-options-social',
	'subsection' => true,
	'fields' => array(
		array(
			'id' => 'social_delicious',
			'type' => 'text',
			'title' => esc_html__( 'Delicious URL', 'presso' ), 
			'subtitle' => esc_html__( 'Enter URL to your account page', 'presso' ),
			'placeholder' => 'https://',
			'validate' => 'url',
		),
		array(
			'id' => 'social_digg',
			'type' => 'text',
			'title' => esc_html__( 'Digg URL', 'presso' ), 
			'subtitle' => esc_html__( 'Enter URL to your account page', 'presso' ),
			'placeholder' => 'https://',
			'validate' => 'url',
		),
		array(
			'id' => 'social_dribbble',
			'type' => 'text',
			'title' => esc_html__( 'Dribbble URL', 'presso' ), 
			'subtitle' => esc_html__( 'Enter URL to your account page', 'presso' ),
			'placeholder' => 'https://',
			'validate' => 'url',
		),
		array(
			'id' => 'social_facebook',
			'type' => 'text',
			'title' => esc_html__( 'Facebook URL', 'presso' ), 
			'subtitle' => esc_html__( 'Enter URL to your account page', 'presso' ),
			'placeholder' => 'https://',
			'default' => 'https://facebook.com',
			'validate' => 'url',
		),
		array(
			'id' => 'social_flickr',
			'type' => 'text',
			'title' => esc_html__( 'Flickr URL', 'presso' ), 
			'subtitle' => esc_html__( 'Enter URL to your account page', 'presso' ),
			'placeholder' => 'https://',
			'validate' => 'url',
		),
		array(
			'id' => 'social_forrst',
			'type' => 'text',
			'title' => esc_html__( 'Forrst URL', 'presso' ), 
			'subtitle' => esc_html__( 'Enter URL to your account page', 'presso' ),
			'placeholder' => 'https://',
			'validate' => 'url',
		),
		array(
			'id' => 'social_github',
			'type' => 'text',
			'title' => esc_html__( 'Github URL', 'presso' ), 
			'subtitle' => esc_html__( 'Enter URL to your account page', 'presso' ),
			'placeholder' => 'https://',
			'validate' => 'url',
		),
		array(
			'id' => 'social_googleplus',
			'type' => 'text',
			'title' => esc_html__( 'Google+ URL', 'presso' ), 
			'subtitle' => esc_html__( 'Enter URL to your account page', 'presso' ),
			'placeholder' => 'https://',
			'validate' => 'url',
			'default' => 'https://plus.google.com',
		),
		array(
			'id' => 'social_instagram',
			'type' => 'text',
			'title' => esc_html__( 'Instagram URL', 'presso' ), 
			'subtitle' => esc_html__( 'Enter URL to your account page', 'presso' ),
			'placeholder' => 'https://',
			'validate' => 'url',
		),
		array(
			'id' => 'social_lastfm',
			'type' => 'text',
			'title' => esc_html__( 'Last.fm URL', 'presso' ), 
			'subtitle' => esc_html__( 'Enter URL to your account page', 'presso' ),
			'placeholder' => 'https://',
			'validate' => 'url',
		),
		array(
			'id' => 'social_linkedin',
			'type' => 'text',
			'title' => esc_html__( 'Linkedin URL', 'presso' ), 
			'subtitle' => esc_html__( 'Enter URL to your account page', 'presso' ),
			'placeholder' => 'https://',
			'validate' => 'url',
		),
		array(
			'id' => 'social_pinterest',
			'type' => 'text',
			'title' => esc_html__( 'Pinterest URL', 'presso' ), 
			'subtitle' => esc_html__( 'Enter URL to your account page', 'presso' ),
			'placeholder' => 'https://',
			'validate' => 'url',
		),
		array(
			'id' => 'social_rss',
			'type' => 'text',
			'title' => esc_html__( 'Rss URL', 'presso' ), 
			'subtitle' => esc_html__( 'Enter URL to your account page', 'presso' ),
			'placeholder' => 'https://',
			'validate' => 'url',
		),
		array(
			'id' => 'social_skype',
			'type' => 'text',
			'title' => esc_html__( 'Skype URL', 'presso' ), 
			'subtitle' => esc_html__( 'Enter URL to your account page', 'presso' ),
			'placeholder' => 'https://',
			'validate' => 'url',
		),
		array(
			'id' => 'social_tumblr',
			'type' => 'text',
			'title' => esc_html__( 'Tumblr URL', 'presso' ), 
			'subtitle' => esc_html__( 'Enter URL to your account page', 'presso' ),
			'placeholder' => 'https://',
			'validate' => 'url',
		),
		array(
			'id' => 'social_twitter',
			'type' => 'text',
			'title' => esc_html__( 'Twitter URL', 'presso' ), 
			'subtitle' => esc_html__( 'Enter URL to your account page', 'presso' ),
			'placeholder' => 'https://',
			'default' => 'https://twitter.com',
			'validate' => 'url',
		),
		array(
			'id' => 'social_vimeo',
			'type' => 'text',
			'title' => esc_html__( 'Vimeo URL', 'presso' ), 
			'subtitle' => esc_html__( 'Enter URL to your account page', 'presso' ),
			'placeholder' => 'https://',
			'validate' => 'url',
		),
		array(
			'id' => 'social_yahoo',
			'type' => 'text',
			'title' => esc_html__( 'Yahoo URL', 'presso' ), 
			'subtitle' => esc_html__( 'Enter URL to your account page', 'presso' ),
			'placeholder' => 'https://',
			'validate' => 'url',
		),
		array(
			'id' => 'social_youtube',
			'type' => 'text',
			'title' => esc_html__( 'Youtube URL', 'presso' ), 
			'subtitle' => esc_html__( 'Enter URL to your account page', 'presso' ),
			'placeholder' => 'https://',
			'validate' => 'url',
		),
	),
) );


Redux::setSection( $vw_opt_name, array(
	'title' => esc_html__( 'Typography', 'presso' ),
	'desc' => '',
	'id' => 'presso-options-site-typography',
	'icon' => 'el el-fontsize',
	'fields' => array(
		array(
			'id' => 'typography_header',
			'type' => 'typography',
			'title' => esc_html__( 'Heading Text', 'presso' ),
			//'compiler' => true, // Use if you want to hook in your own CSS compiler
			'google' => true, // Disable google fonts. Won't work if you haven't defined your google api key
			'font-backup' => true, // Select a backup non-google font in addition to a google font
			//'font-style' => false, // Includes font-style and weight. Can use font-style or font-weight to declare
			//'subsets' => false, // Only appears if google is true and subsets not set to false
			'font-size' => false,
			'line-height' => false,
			//'word-spacing' => true, // Defaults to false
			'letter-spacing'=> true, // Defaults to false
			//'color' => false,
			'text-align' => false,
			'text-transform' => true,
			//'preview' => false, // Disable the previewer
			'all_styles' => true, // Enable all Google Font style/weight variations to be added to the page
			'output' => array(
				'h1, h2, h3, h4, h5, h6, .vw-header-font',
				'#wp-calendar caption',
				'.vw-accordion-header-text',
				'.vw-review-item-title',
				'.vw-previous-link-page, .vw-next-link-page',
				'.vw-quote',
				'blockquote',
				'.vw-comment__author',
				'.widget_shopping_cart_content .mini_cart_item a:nth-child(2)',
				'.vw-post-content .vw-post-box__link',
				), // An array of CSS selectors to apply this font style to dynamically
			'units' => 'px', // Defaults to px
			'subtitle' => esc_html__( 'Choose font for header text', 'presso' ),
			'default' => array(
				'color' => '#333',
				'font-weight' => '700',
				'font-family' => 'Oswald',
				'google' => true,
				'text-transform' => 'uppercase',
				'letter-spacing' => '0px',
			),
		),

		array(
			'id' => 'presso-options-typography-heading-tags',
			'type' => 'section',
			'indent' => true,
		),

		array(
			'id' => 'typography_h1',
			'type' => 'typography',
			'title' => esc_html__( 'Heading 1 (H1)', 'presso' ),
			'font-style' => false,
			'font-family' => false,
			'font-size' => true,
			'font-weight' => false,
			'line-height' => false,
			'color' => false,
			'text-align' => false,
			'output' => array( 'h1' ),
			'units' => 'px',
			'default' => array(
				'font-size' => '36px',
			),
		),

		array(
			'id' => 'typography_h2',
			'type' => 'typography',
			'title' => esc_html__( 'Heading 2 (H2)', 'presso' ),
			'font-style' => false,
			'font-family' => false,
			'font-size' => true,
			'font-weight' => false,
			'line-height' => false,
			'color' => false,
			'text-align' => false,
			'output' => array( 'h2' ),
			'units' => 'px',
			'default' => array(
				'font-size' => '30px',
			),
		),

		array(
			'id' => 'typography_h3',
			'type' => 'typography',
			'title' => esc_html__( 'Heading 3 (H3)', 'presso' ),
			'font-style' => false,
			'font-family' => false,
			'font-size' => true,
			'font-weight' => false,
			'line-height' => false,
			'color' => false,
			'text-align' => false,
			'output' => array( 'h3' ),
			'units' => 'px',
			'default' => array(
				'font-size' => '24px',
			),
		),

		array(
			'id' => 'typography_h4',
			'type' => 'typography',
			'title' => esc_html__( 'Heading 4 (H4)', 'presso' ),
			'font-style' => false,
			'font-family' => false,
			'font-size' => true,
			'font-weight' => false,
			'line-height' => false,
			'color' => false,
			'text-align' => false,
			'output' => array( 'h4' ),
			'units' => 'px',
			'default' => array(
				'font-size' => '18px',
			),
		),

		array(
			'id' => 'typography_h5',
			'type' => 'typography',
			'title' => esc_html__( 'Heading 5 (H5)', 'presso' ),
			'font-style' => false,
			'font-family' => false,
			'font-size' => true,
			'font-weight' => false,
			'line-height' => false,
			'color' => false,
			'text-align' => false,
			'output' => array( 'h5' ),
			'units' => 'px',
			'default' => array(
				'font-size' => '14px',
			),
		),

		array(
			'id' => 'typography_h6',
			'type' => 'typography',
			'title' => esc_html__( 'Heading 6 (H6)', 'presso' ),
			'font-style' => false,
			'font-family' => false,
			'font-size' => true,
			'font-weight' => false,
			'line-height' => false,
			'color' => false,
			'text-align' => false,
			'output' => array( 'h6' ),
			'units' => 'px',
			'default' => array(
				'font-size' => '12px',
			),
		),

		array(
			'id' => 'presso-options-typography-body',
			'type' => 'section',
			'indent' => false,
		),

		array(
			'id' => 'typography_body',
			'type' => 'typography',
			'title' => esc_html__( 'Body', 'presso' ),
			//'compiler' => true, // Use if you want to hook in your own CSS compiler
			'google' => true, // Disable google fonts. Won't work if you haven't defined your google api key
			'font-backup' => true, // Select a backup non-google font in addition to a google font
			//'font-style' => false, // Includes font-style and weight. Can use font-style or font-weight to declare
			//'subsets' => false, // Only appears if google is true and subsets not set to false
			//'font-size' => false,
			'line-height' => false,
			//'word-spacing' => true, // Defaults to false
			//'letter-spacing'=> true, // Defaults to false
			//'color' => false,
			'text-align' => false,
			//'preview' => false, // Disable the previewer
			'all_styles' => true, // Enable all Google Font style/weight variations to be added to the page
			'output' => array( 'body', 'cite', '.vw-quote-cite' ), // An array of CSS selectors to apply this font style to dynamically
			// 'compiler' => array('h2.site-description-compiler'), // An array of CSS selectors to apply this font style to dynamically
			'units' => 'px', // Defaults to px
			'subtitle' => esc_html__( 'Choose font for body text', 'presso' ),
			'default' => array(
				'color' => '#666',
				'font-weight' => '400',
				'font-family' => 'Open Sans',
				'google' => true,
				'font-size' => '14px',
			),
		),

		array(
			'id' => 'typography_topbar',
			'type' => 'typography',
			'title' => esc_html__( 'Top Bar', 'presso' ),
			//'compiler' => true, // Use if you want to hook in your own CSS compiler
			'google' => true, // Disable google fonts. Won't work if you haven't defined your google api key
			'font-backup' => true, // Select a backup non-google font in addition to a google font
			//'font-style' => false, // Includes font-style and weight. Can use font-style or font-weight to declare
			//'subsets' => false, // Only appears if google is true and subsets not set to false
			//'font-size' => false,
			'line-height' => false,
			//'word-spacing' => true, // Defaults to false
			'letter-spacing'=> true, // Defaults to false
			'color' => false,
			'text-align' => false,
			//'preview' => false, // Disable the previewer
			'all_styles' => true, // Enable all Google Font style/weight variations to be added to the page
			'output' => array( '.vw-top-bar' ), // An array of CSS selectors to apply this font style to dynamically
			// 'compiler' => array('h2.site-description-compiler'), // An array of CSS selectors to apply this font style to dynamically
			'units' => 'px', // Defaults to px
			'subtitle' => esc_html__( 'Choose font for widget title text', 'presso' ),
			'default' => array(
				'font-weight' => '400',
				'font-family' => 'Oswald',
				'google' => true,
				'font-size' => '13px',
				'text-transform' => 'uppercase',
				'letter-spacing' => '0px',
			),
		),

		array(
			'id' => 'typography_widget_title',
			'type' => 'typography',
			'title' => esc_html__( 'Widget Title', 'presso' ),
			//'compiler' => true, // Use if you want to hook in your own CSS compiler
			'google' => true, // Disable google fonts. Won't work if you haven't defined your google api key
			'font-backup' => true, // Select a backup non-google font in addition to a google font
			//'font-style' => false, // Includes font-style and weight. Can use font-style or font-weight to declare
			//'subsets' => false, // Only appears if google is true and subsets not set to false
			//'font-size' => false,
			'line-height' => false,
			//'word-spacing' => true, // Defaults to false
			'letter-spacing'=> true, // Defaults to false
			'color' => true,
			'text-align' => false,
			//'preview' => false, // Disable the previewer
			'all_styles' => true, // Enable all Google Font style/weight variations to be added to the page
			'output' => array( '.widget-title' ), // An array of CSS selectors to apply this font style to dynamically
			// 'compiler' => array('h2.site-description-compiler'), // An array of CSS selectors to apply this font style to dynamically
			'units' => 'px', // Defaults to px
			'subtitle' => esc_html__( 'Choose font for widget title text', 'presso' ),
			'default' => array(
				'color' => '#333',
				'font-weight' => '700',
				'font-family' => 'Oswald',
				'google' => true,
				'font-size' => '33px',
				'text-transform' => 'uppercase',
				'letter-spacing' => '1px',
			),
		),

		array(
			'id' => 'typography_composer_title',
			'type' => 'typography',
			'title' => esc_html__( 'Section Title', 'presso' ),
			//'compiler' => true, // Use if you want to hook in your own CSS compiler
			'google' => true, // Disable google fonts. Won't work if you haven't defined your google api key
			'font-backup' => true, // Select a backup non-google font in addition to a google font
			//'font-style' => false, // Includes font-style and weight. Can use font-style or font-weight to declare
			//'subsets' => false, // Only appears if google is true and subsets not set to false
			//'font-size' => false,
			'line-height' => false,
			//'word-spacing' => true, // Defaults to false
			'letter-spacing'=> true, // Defaults to false
			'color' => true,
			'text-align' => false,
			//'preview' => false, // Disable the previewer
			'all_styles' => true, // Enable all Google Font style/weight variations to be added to the page
			'output' => array( 'body .vwspc-section-title' ), // An array of CSS selectors to apply this font style to dynamically
			// 'compiler' => array('h2.site-description-compiler'), // An array of CSS selectors to apply this font style to dynamically
			'units' => 'px', // Defaults to px
			'subtitle' => esc_html__( 'Choose font for section title text in Page Composer', 'presso' ),
			'default' => array(
				'color' => '#333',
				'font-weight' => '700',
				'font-family' => 'Oswald',
				'google' => true,
				'font-size' => '33px',
				'text-transform' => 'uppercase',
				'letter-spacing' => '1px',
			),
		),

		array(
			'id' => 'typography_super_title',
			'type' => 'typography',
			'title' => esc_html__( 'Super-title', 'presso' ),
			'font-style' => false,
			'font-family' => false,
			'font-size' => true,
			'font-weight' => false,
			'line-height' => false,
			'color' => false,
			'text-align' => false,
			'output' => array( '.vw-super-title' ),
			'units' => 'px',
			'default' => array(
				'font-size' => '13px',
			),
		),

		array(
			'id' => 'typography_post_box_meta',
			'type' => 'typography',
			'title' => esc_html__( 'Post Meta', 'presso' ),
			'font-style' => false,
			'font-family' => false,
			'font-size' => true,
			'font-weight' => false,
			'line-height' => false,
			'color' => false,
			'text-align' => false,
			'output' => array( '.vw-post-box .vw-post-box__meta' ),
			'units' => 'px',
			'default' => array(
				'font-size' => '11px',
			),
		),

		array(
			'id' => 'typography_post_box_categories',
			'type' => 'typography',
			'title' => esc_html__( 'Category Tag', 'presso' ),
			'font-style' => false,
			'font-family' => false,
			'font-size' => true,
			'font-weight' => false,
			'line-height' => false,
			'color' => false,
			'text-align' => false,
			'output' => array( '.vw-categories' ),
			'units' => 'px',
			'default' => array(
				'font-size' => '11px',
			),
		),

		array(
			'id' => 'typography_post_footer_title',
			'type' => 'typography',
			'title' => esc_html__( 'Post Footer Section Title', 'presso' ),
			'font-style' => false,
			'font-family' => false,
			'font-size' => true,
			'font-weight' => false,
			'line-height' => false,
			'color' => false,
			'text-align' => false,
			'units' => 'px',
			'default' => array(
				'font-size' => '36px',
			),
		),
	),
) );





Redux::setSection( $vw_opt_name, array(
	'title' => esc_html__( 'Custom Fonts', 'presso' ),
	'desc' => 'Upload font files here',
	'id' => 'presso-options-custom-fonts',
	'subsection' => true,
	'fields' => array(
		array(
			'id' => 'vw-options-typography-custom-font-1',
			'type' => 'section',
			'title' => esc_html__( 'Custom Font 1', 'presso' ),
			'indent' => true,
		),

		array(
			'id'=>'custom_font1_ttf',
			'type' => 'media',
			'preview'=> false,
			'mode'=> 'application',
			'title' => esc_html__( '.TTF/.OTF Font File', 'presso' ),
		),
		array(
			'id'=>'custom_font1_woff',
			'type' => 'media',
			'preview'=> false,
			'mode'=> 'application',
			'title' => esc_html__( '.WOFF Font File', 'presso' ),
		),
		array(
			'id'=>'custom_font1_eot',
			'type' => 'media',
			'preview'=> false,
			'mode'=> 'application',
			'title' => esc_html__( '.EOT Font File', 'presso' ),
		),


		array(
			'id' => 'vw-options-typography-custom-font-2',
			'type' => 'section',
			'title' => esc_html__( 'Custom Font 2', 'presso' ),
			'indent' => true,
		),

		array(
			'id'=>'custom_font2_ttf',
			'type' => 'media',
			'preview'=> false,
			'mode'=> 'application',
			'title' => esc_html__( '.TTF/.OTF Font File', 'presso' ),
		),
		array(
			'id'=>'custom_font2_woff',
			'type' => 'media',
			'preview'=> false,
			'mode'=> 'application',
			'title' => esc_html__( '.WOFF Font File', 'presso' ),
		),
		array(
			'id'=>'custom_font2_eot',
			'type' => 'media',
			'preview'=> false,
			'mode'=> 'application',
			'title' => esc_html__( '.EOT Font File', 'presso' ),
		),
		
	),
) );




/**
Logo
 */

Redux::setSection( $vw_opt_name, array(
	'title' => esc_html__( 'Logo', 'presso' ),
	'desc' => '',
	'id' => 'presso-options-logo',
	'icon' => 'el el-star-empty',
	'fields' => array(
		array(
			'id'		=> 'logo',
			'type'		=> 'media',
			'title' => esc_html__( 'Original Logo', 'presso' ), 
			'subtitle' => esc_html__( 'Upload the original site logo', 'presso' ),
		),
		array(
			'id'		=> 'logo_2x',
			'type'		=> 'media',
			'title' => esc_html__( 'Retina Logo', 'presso' ), 
			'subtitle' => esc_html__( 'The retina logo must be double size (2X) of the original logo', 'presso' ),
		),
		array(
			'id' => 'show_site_tagline',
			'type' => 'switch',
			'title' => esc_html__( 'Show Site Tagline', 'presso' ), 
			'desc' => esc_html__( 'You can set the site tagline at "Settings > General"', 'presso' ),
			'default' => 1
		),
		array(
			'id' => 'logo_spacing',
			'type' => 'spacing',
			'title' => esc_html__( 'Logo Spacing', 'presso' ), 
			'subtitle' => esc_html__( 'Adjust logo spacing here', 'presso' ),
			'mode' => 'padding',
			'units'=> array( 'px' ),
			'output' => array( '.vw-header__logo' ),
			'default' => array(
				'padding-top' => '42px',
				'padding-bottom' => '42px',
				'padding-left' => '15px',
				'padding-right' => '30px',
				'units' => 'px',
			),
		),
		array(
			'id' => 'mobile-logo-section',
			'type' => 'section',
			'title' => esc_html__( 'Mobile Logo', 'presso' ),
			'subtitle' => esc_html__( 'An alternative logo for mobile', 'presso' ),
			'indent' => true,
		),

		array(
			'id'		=> 'mobile_logo',
			'type'		=> 'media',
			'title' => esc_html__( 'Original Logo', 'presso' ), 
			'subtitle' => esc_html__( 'Upload the original site logo', 'presso' ),
		),
		array(
			'id'		=> 'mobile_logo_2x',
			'type'		=> 'media',
			'title' => esc_html__( 'Retina Logo', 'presso' ), 
			'subtitle' => esc_html__( 'The retina logo must be double size (2X) of the original logo', 'presso' ),
		),
		array(
			'id' => 'mobile_logo_spacing',
			'type' => 'spacing',
			'title' => esc_html__( 'Logo Spacing', 'presso' ), 
			'subtitle' => esc_html__( 'Adjust logo spacing here', 'presso' ),
			'mode' => 'padding',
			'units'=> array( 'px' ),
			'default' => array(
				'padding-top' => '25px',
				'padding-bottom' => '25px',
				'padding-left' => '0px',
				'padding-right' => '0px',
				'units' => 'px',
			),
		),
	),
) );





/**
Header
 */

Redux::setSection( $vw_opt_name, array(
	'title' => esc_html__( 'Header', 'presso' ),
	'desc' => '',
	'id' => 'presso-options-site-header',
	'fields' => array(

		array(
			'id'=>'site_header_layout',
			'type' => 'select',
			'title' => esc_html__( 'Site Header Layout', 'presso' ), 
			'subtitle' => esc_html__( 'Select a site header style', 'presso' ),
			'desc' => esc_html__( 'When choosing "Custom 1" or "Custom 2", You need to override the template file from child theme. Please see the file name to be overriden on documentation', 'presso' ),
			'default' => 'default',
			'options' => array(
				'default' => esc_html__( 'Logo / Ads', 'presso' ),
				'center' => esc_html__( 'Centered Logo', 'presso' ),
				'right-menu' => esc_html__( 'Logo / Menu', 'presso' ),
				'custom-1' => esc_html__( 'Custom 1', 'presso' ),
				'custom-2' => esc_html__( 'Custom 2', 'presso' ),
			),
		),

		array(
			'id'		=> 'site_header_padding',
			'type'		=> 'spacing',
			'title' => esc_html__( 'Site Header Padding', 'presso' ), 
			'subtitle' => esc_html__( 'A top and bottom padding for site header', 'presso' ),
			'output'	=> array( '.vw-site-header__floating' ),
			'units'	=> 'px',
			'top'	=> true,
			'right'	=> false,
			'bottom'=> true,
			'left'	=> false,
			'default'	=> array(
				'top' => '11px',
				'bottom' => '11px',
			),
		),

		array(
			'id'=>'header_ads',
			'type' => 'ace_editor',
			'theme' => 'monokai',
			'mode' => 'html',
			'title' => esc_html__( 'Header Ads','presso' ),
			'subtitle' => esc_html__( 'Paste your ads code here. <strong>&lt;script&gt;</strong> tag is required', 'presso' ),
		),


		array(
			'id' => 'presso-options-site-header-bg-color',
			'type' => 'section',
			'title' => esc_html__( 'Color', 'presso' ),
			'indent' => true,
		),

		array(
			'id'=>'header_background',
			'type' => 'color', 
			'title' => esc_html__( 'Background', 'presso' ),
			'desc' => esc_html__( 'A Background color of header', 'presso' ),
			'mode' => 'background',
			'transparent'=> false,
			'output' => array( '.vw-header' ),
			'default' => '#fff'
		),

		array(
			'id'=>'header_text_color',
			'type' => 'color', 
			'title' => esc_html__( 'Text Color', 'presso' ),
			'desc' => esc_html__( 'Text color in header', 'presso' ),
			'output' => array( '.vw-header', '.vw-header .vw-instant-search i' ),
			'default' => '#191919'
		),
	),
) );


Redux::setSection( $vw_opt_name, array(
	'title' => esc_html__( 'Top Bar', 'presso' ),
	'desc' => '',
	'id' => 'presso-options-top-bar',
	'subsection' => true,
	'fields' => array(
		array(
			'id'=>'topbar_layout',
			'type' => 'select',
			'title' => esc_html__( 'Top Bar Layout', 'presso' ), 
			'subtitle' => esc_html__( 'Select a top-bar layout', 'presso' ),
			'desc' => esc_html__( 'When choosing "Custom 1" or "Custom 2", You need to override the template file from child theme. Please see the file name to be overriden in documentation', 'presso' ),
			'options' => array(
				'none' => esc_html__( 'Not Shown', 'presso' ),
				'default' => esc_html__( 'Top Menu / Site Social Networks', 'presso' ),
				'menu-text' => esc_html__( 'Top Menu / Custom Text', 'presso' ),
				'ticker-social' => esc_html__( 'Post Ticker / Site Social Networks', 'presso' ),
				'custom-1' => esc_html__( 'Custom 2', 'presso' ),
				'custom-2' => esc_html__( 'Custom 2', 'presso' ),
			),
			'default' => 'default',
		),

		array(
			'id'=>'topbar_custom_text',
			'type' => 'textarea', 
			'title' => esc_html__( 'Custom Text', 'presso' ),
			'subtitle' => esc_html__( 'Enter a text', 'presso' ),
			'default' => '[icon icon="icon-entypo-phone"] Call 123-456-789',
		),

		array(
			'id'=>'show_today_on_topbar',
			'type' => 'switch', 
			'title' => esc_html__( 'Show current date on top bar', 'presso' ),
			'subtitle' => esc_html__( 'Turn on this option to show a current date', 'presso' ),
			'default' => 1,
		),

		array(
			'id' => 'top-bar-post-ticker-section',
			'type' => 'section',
			'title' => esc_html__( 'Post Ticker', 'presso' ),
			'indent' => true,
		),

		array(
			'id'=>'ticker_source',
			'type' => 'select',
			'title' => esc_html__( 'Post Ticker Source', 'presso' ), 
			'subtitle' => esc_html__( 'Select a source of breaking news', 'presso' ),
			'options' => array(
				'latest' => esc_html__( 'Latest Posts', 'presso' ),
				'featured' => esc_html__( 'Featured Posts', 'presso' ),
				'random' => esc_html__( 'Random', 'presso' ),
			),
			'default' => 'latest',
		),

		array(
			'id' => 'ticker_count',
			'type' => 'text',
			'title' => esc_html__( 'Number of Posts', 'presso' ), 
			'subtitle' => esc_html__( 'Enter a number of posts to be displayed in post ticker', 'presso' ),
			'validate' => 'numeric',
			'default' => 4,
		),


		array(
			'id' => 'top-bar-color-section',
			'type' => 'section',
			'title' => esc_html__( 'Color', 'presso' ),
			'indent' => true,
		),

		array(
			'id'=>'topbar_background',
			'type' => 'color', 
			'title' => esc_html__( 'Background', 'presso' ),
			'mode' => 'background',
			'transparent'=> false,
			'output' => array( '.vw-top-bar' ),
			'default' => '#333'
		),

		array(
			'id'=>'topbar_text_color',
			'type' => 'color', 
			'title' => esc_html__( 'Text Color', 'presso' ),
			'output' => array( '.vw-top-bar' ),
			'default' => '#eee'
		),

		
	),
) );


Redux::setSection( $vw_opt_name, array(
	'title' => esc_html__( 'Main Menu', 'presso' ),
	'desc' => '',
	'id' => 'presso-options-main-menu',
	'subsection' => true,
	'fields' => array(
		array(
			'id' => 'typography_main_menu',
			'type' => 'typography',
			'title' => esc_html__( 'Main Menu Font', 'presso' ),
			'async_typography' => false,
			//'compiler' => true, // Use if you want to hook in your own CSS compiler
			'google' => true, // Disable google fonts. Won't work if you haven't defined your google api key
			'font-backup' => true, // Select a backup non-google font in addition to a google font
			//'font-style' => false, // Includes font-style and weight. Can use font-style or font-weight to declare
			//'subsets' => false, // Only appears if google is true and subsets not set to false
			//'font-size' => false,
			'line-height' => false,
			//'word-spacing' => true, // Defaults to false
			'letter-spacing'=> true, // Defaults to false
			'color' => false,
			'text-align' => false,
			'text-transform' => true,
			//'preview' => false, // Disable the previewer
			'all_styles' => false, // Enable all Google Font style/weight variations to be added to the page
			'output' => array( '.vw-menu-main .main-menu-link' ), // An array of CSS selectors to apply this font style to dynamically
			// 'compiler' => array('h2.site-description-compiler'), // An array of CSS selectors to apply this font style to dynamically
			'units' => 'px', // Defaults to px
			'subtitle' => esc_html__( 'Choose font for main menu text', 'presso' ),
			'default' => array(
				'font-weight' => '400',
				'font-family' => 'Oswald',
				'font-size' => '16px',
				'google' => true,
				'text-transform' => 'uppercase',
				'letter-spacing' => '0px',
			),
		),
		
		array(
			'id'=>'main_menu_background',
			'type' => 'color', 
			'title' => esc_html__( 'Background', 'presso' ),
			'mode' => 'background',
			'transparent'=> true,
			'output' => array( '.vw-menu-main' ),
			'default' => '#333',
		),

		array(
			'id'=>'main_main_menu_link',
			'type' => 'color', 
			'title' => esc_html__( 'Main Menu Link Color', 'presso' ),
			'visited' => false,
			'active' => false,
			'output' => array( '.vw-menu-main .main-menu-link' ),
			'default' => '#fff',
		),

		// array(
		// 	'id'=>'main_main_menu_link_hover_background',
		// 	'type' => 'color', 
		// 	'title' => esc_html__( 'Main Menu Link Hover Background Color', 'presso' ),
		// 	'mode' => 'background',
		// 	'transparent'=> false,
		// 	'output' => array( '.vw-menu-main .main-menu-item:hover' ),
		// 	'default' => '#222'
		// ),

		array(
			'id'=>'main_sub_menu_link',
			'type' => 'color', 
			'title' => esc_html__( 'Sub-Menu Link Color', 'presso' ),
			'visited' => false,
			'active' => false,
			'output' => array( '.vw-menu-main .sub-menu-link' ),
			'default' => '#2d2d2d',
		),

		array(
			'id'=>'main_sub_menu_background',
			'type' => 'color', 
			'title' => esc_html__( 'Sub-Menu Background', 'presso' ),
			'mode' => 'background',
			'transparent'=> false,
			'output' => array( '.vw-menu-main .sub-menu-wrapper' ),
			'default' => '#f7f7f7'
		),
	),
) );


Redux::setSection( $vw_opt_name, array(
	'title' => esc_html__( 'Footer', 'presso' ),
	'desc' => '',
	'id' => 'presso-options-footer',
	'fields' => array(

		array(
			'id'=>'site_footer_layout',
			'type' => 'image_select',
			'title' => esc_html__( 'Footer Layout', 'presso' ), 
			'subtitle' => esc_html__( 'Select footer sidebar layout', 'presso' ),
			'options' => array(
					'1' => array('alt' => '1/4 + 1/4 + 1/4 + 1/4 Column', 'img' => PRESSO_CONST_REDUX_ASSET_URL.'/footer-layout-1_4-1_4-1_4-1_4.png'),
					'2' => array('alt' => '1/2 + 1/4 + 1/4 Column', 'img' => PRESSO_CONST_REDUX_ASSET_URL.'/footer-layout-1_2-1_4-1_4.png'),
					'3' => array('alt' => '1/4 + 1/4 + 1/2 Column', 'img' => PRESSO_CONST_REDUX_ASSET_URL.'/footer-layout-1_4-1_4-1_2.png'),
					'4' => array('alt' => '1/2 + 1/2 Column', 'img' => PRESSO_CONST_REDUX_ASSET_URL.'/footer-layout-1_2-1_2.png'),
					'5' => array('alt' => '1/3 + 1/3 + 1/3 Column', 'img' => PRESSO_CONST_REDUX_ASSET_URL.'/footer-layout-1_3-1_3-1_3.png'),
					'6' => array('alt' => '2/3 + 1/3 Column', 'img' => PRESSO_CONST_REDUX_ASSET_URL.'/footer-layout-2_3-1_3.png'),
					'7' => array('alt' => '1/3 + 2/3 Column', 'img' => PRESSO_CONST_REDUX_ASSET_URL.'/footer-layout-1_3-2_3.png'),
					'8' => array('alt' => '1/4 + 1/2 + 1/4 Column', 'img' => PRESSO_CONST_REDUX_ASSET_URL.'/footer-layout-1_4-1_2-1_4.png'),
					'9' => array('alt' => '1/1 Column', 'img' => PRESSO_CONST_REDUX_ASSET_URL.'/footer-layout-1_1.png'),
					'10' => array('alt' => '1/1 Column', 'img' => PRESSO_CONST_REDUX_ASSET_URL.'/footer-layout-1_1b.png'),
					'none' => array('alt' => 'No footer', 'img' => PRESSO_CONST_REDUX_ASSET_URL.'/footer-layout-none.png'),
				),
			'default' => '5',
		),

		array(
			'id' => 'footer-photo-stream',
			'type' => 'section',
			'title' => esc_html__( 'Photo Stream', 'presso' ),
			'indent' => true,
		),

		array(
			'id'=>'enable_photo_stream',
			'type' => 'select',
			'title' => esc_html__( 'Enable Photo Stream', 'presso' ), 
			'subtitle' => esc_html__( 'The photo stream will be shown in footer when enabled.', 'presso' ),
			'options' => array(
				'none' => esc_html__( 'Not Shown', 'presso' ),
				'instagram' => esc_html__( 'Show', 'presso' ),
			),
			'default' => 'none',
		),

		array(
			'id' => 'instagram_access_token',
			'type' => 'text',
			'title' => esc_html__( 'Instagram Access Token', 'presso' ), 
			'subtitle' => esc_html__( 'Enter instagram access token.', 'presso' ),
			'desc' => wp_kses_post( __( 'Find it <a href="http://instagram.pixelunion.net/" target="_blank">here</a>.', 'presso' ) ),
		),

		array(
			'id'=>'instagram_photo_count',
			'type' => 'spinner',
			'title' => esc_html__( 'Number of photo', 'presso' ), 
			'subtitle' => esc_html__( 'The number of photo to be displayed', 'presso' ),
			'min' => '6',
			'max' => '12',
			'default' => '9',
		),

		array(
			'id' => 'footer-color-section',
			'type' => 'section',
			'title' => esc_html__( 'Color', 'presso' ),
			'indent' => true,
		),

		array(
			'id'=>'footer_background',
			'type' => 'background', 
			'title' => esc_html__( 'Background', 'presso' ),
			'output' => array( '.vw-footer' ),
			'default' => array(
				'background-color' => '#191919',
			),
		),
		array(
			'id'=>'footer_header_color',
			'type' => 'color', 
			'title' => esc_html__( 'Header Color', 'presso' ),
			'subtitle' => esc_html__( 'Color of header text', 'presso' ),
			'transparent'=> false,
			'output' => array(
				'.vw-footer h1',
				'.vw-footer h2',
				'.vw-footer h3',
				'.vw-footer h4',
				'.vw-footer h5',
				'.vw-footer h6',
				 ),
			'default' => '#fff'
		),
		array(
			'id'=>'footer_widget_title_color',
			'type' => 'color', 
			'title' => esc_html__( 'Widget Title Color', 'presso' ),
			'subtitle' => esc_html__( 'Color of widget title', 'presso' ),
			'transparent'=> false,
			'output' => array(
				'.vw-footer .widget-title',
				 ),
			'default' => '#3facd6'
		),
		array(
			'id'=>'footer_color',
			'type' => 'color', 
			'title' => esc_html__( 'Text/Link Color', 'presso' ),
			'transparent'=> false,
			'output' => array( '.vw-footer' ),
			'default' => '#9a9a9a'
		),
	),
) );


Redux::setSection( $vw_opt_name, array(
	'title' => esc_html__( 'Bottom Bar', 'presso' ),
	'desc' => '',
	'id' => 'presso-options-bottom-bar',
	'subsection' => true,
	'fields' => array(
		array(
			'id'=>'bottombar_layout',
			'type' => 'select',
			'title' => esc_html__( 'Bottom Bar Layout', 'presso' ), 
			'subtitle' => esc_html__( 'Select a bottom-bar layout', 'presso' ),
			'desc' => esc_html__( 'When choosing "Custom 1" or "Custom 2", You need to override the template file from child theme. Please see the file name to be overriden on documentation', 'presso' ),
			'options' => array(
				'none' => esc_html__( 'Not Shown', 'presso' ),
				'default' => esc_html__( 'Copyright / Bottom Menu', 'presso' ),
				'copyright' => esc_html__( 'Copyright', 'presso' ),
				'custom-1' => esc_html__( 'Custom 1', 'presso' ),
				'custom-2' => esc_html__( 'Custom 2', 'presso' ),
			),
			'default' => 'default',
		),

		array(
			'id'=>'copyright_text',
			'type' => 'textarea', 
			'title' => esc_html__( 'Copyright', 'presso' ),
			'subtitle' => esc_html__( 'Enter copyright text', 'presso' ),
			'default' => 'Copyright &copy;, All Rights Reserved',
		),

		array(
			'id' => 'bottom-bar-color-section',
			'type' => 'section',
			'title' => esc_html__( 'Color', 'presso' ),
			'indent' => true,
		),

		array(
			'id'=>'bottombar_background',
			'type' => 'color', 
			'title' => esc_html__( 'Background', 'presso' ),
			'mode' => 'background',
			'transparent'=> false,
			'output' => array( '.vw-bottom-bar' ),
			'default' => '#111'
		),

		array(
			'id'=>'bottombar_text_color',
			'type' => 'color', 
			'title' => esc_html__( 'Text Color', 'presso' ),
			'output' => array( '.vw-bottom-bar' ),
			'default' => '#f7f7f7'
		),

		
	),
) );




/**
Blog
 */

$vw_loop_layout_options = array(
	'block-a-1' => esc_html__( 'Block A-1', 'presso' ),
	'block-a-2' => esc_html__( 'Block A-2', 'presso' ),
	'block-a-3' => esc_html__( 'Block A-3', 'presso' ),
	'block-b-1' => esc_html__( 'Block B-1', 'presso' ),
	'block-b-2' => esc_html__( 'Block B-2', 'presso' ),
	'block-b-3' => esc_html__( 'Block B-3', 'presso' ),
	'block-c-1' => esc_html__( 'Block C-1', 'presso' ),
	'block-c-2' => esc_html__( 'Block C-2', 'presso' ),
	'block-c-3' => esc_html__( 'Block C-3', 'presso' ),
	'block-c-4' => esc_html__( 'Block C-4', 'presso' ),
	'block-d-1' => esc_html__( 'Block D-1', 'presso' ),
	'block-d-2' => esc_html__( 'Block D-2', 'presso' ),
	'block-d-3' => esc_html__( 'Block D-3', 'presso' ),
	'block-d-4' => esc_html__( 'Block D-4', 'presso' ),
	'block-e-1' => esc_html__( 'Block E-1', 'presso' ),
	'block-e-2' => esc_html__( 'Block E-2', 'presso' ),
	'block-e-3' => esc_html__( 'Block E-3', 'presso' ),
	'block-f-1' => esc_html__( 'Block F-1', 'presso' ),
	'block-f-2' => esc_html__( 'Block F-2', 'presso' ),
	'block-f-3' => esc_html__( 'Block F-3', 'presso' ),
	'block-g-1' => esc_html__( 'Block G-1', 'presso' ),
	'block-g-2' => esc_html__( 'Block G-2', 'presso' ),
	'block-g-3' => esc_html__( 'Block G-3', 'presso' ),
	'block-g-4' => esc_html__( 'Block G-4', 'presso' ),
	'block-g-5' => esc_html__( 'Block G-5', 'presso' ),
	'block-h-1' => esc_html__( 'Block H-1', 'presso' ),
	'block-h-2' => esc_html__( 'Block H-2', 'presso' ),
	'block-h-3' => esc_html__( 'Block H-3', 'presso' ),
	'block-h-4' => esc_html__( 'Block H-4', 'presso' ),
	'block-h-5' => esc_html__( 'Block H-5', 'presso' ),
	'block-i-1' => esc_html__( 'Block I-1', 'presso' ),
	'block-i-2' => esc_html__( 'Block I-2', 'presso' ),
	'block-i-3' => esc_html__( 'Block I-3', 'presso' ),
	'block-i-4' => esc_html__( 'Block I-4', 'presso' ),
	'custom-1' => esc_html__( 'Custom 1', 'presso' ),
	'custom-2' => esc_html__( 'Custom 2', 'presso' ),
	'custom-3' => esc_html__( 'Custom 3', 'presso' ),
	'custom-4' => esc_html__( 'Custom 4', 'presso' ),
);

$vw_loop_layout_options_with_default = array_merge( array( 'default' => 'Default' ), $vw_loop_layout_options );

$vw_sidebar_position_options = array(
	'none' => esc_html__( 'None', 'presso' ),
	'right' => esc_html__( 'Right', 'presso' ),
	'left' => esc_html__( 'Left', 'presso' ),
);

Redux::setSection( $vw_opt_name, array(
	'title' => esc_html__( 'Blog', 'presso' ),
	'desc' => '',
	'id' => 'presso-options-blog',
	'icon' => 'el el-th-large',
	'fields' => array(

		array(
			'id'=>'blog_loop_layout',
			'type' => 'select',
			'title' => esc_html__( 'Default Layout', 'presso' ), 
			'subtitle' => esc_html__( 'Select default blog layout for blog page', 'presso' ),
			'options' => $vw_loop_layout_options,
			'default' => 'block-a-2',
		),

		array(
			'id'=>'blog_sidebar_position',
			'type' => 'select',
			'title' => esc_html__( 'Default Sidebar Position', 'presso' ), 
			'subtitle' => esc_html__( 'Select default sidebar position', 'presso' ),
			'options' => $vw_sidebar_position_options,
			'default' => 'right',
		),

		array(
			'id'=>'blog_sidebar',
			'type' => 'select',
			'title' => esc_html__( 'Default Sidebar', 'presso' ), 
			'subtitle' => esc_html__( 'Select default sidebar', 'presso' ),
			'data' => 'sidebar',
			'default' => 'blog-sidebar',
		),

		array(
			'id'		=> 'blog_excerpt_length',
			'type'		=> 'text',
			'title' => esc_html__( 'Excerpt Length', 'presso' ), 
			'subtitle' => esc_html__( 'The number of first words to be displayed when the custom excerpt is not provided', 'presso' ),
			'validate'	=> 'numeric',
			'default'	=> 30,
		),

		array(
			'id'=>'post_hover_layout',
			'type' => 'select',
			'title' => esc_html__( 'Featured Image Hover Style', 'presso' ), 
			'subtitle' => esc_html__( 'Select a style when hover a featured image', 'presso' ),
			'options' => array(
				'icons' => esc_html__( 'Icons', 'presso' ),
				'link' => esc_html__( 'Direct link to post', 'presso' ),
			),
			'default' => 'icons',
		),

		array(
			'id'=>'enable_more_articles',
			'type' => 'switch', 
			'title' => esc_html__( 'Enable More Stories', 'presso' ),
			'subtitle' => esc_html__( 'Turn on this option to display a floating windows for more story', 'presso' ),
			'default' => 1,
		),

		array(
			'id'=>'show_human_diff_time',
			'type' => 'switch', 
			'title' => esc_html__( 'Display Post Date as Time Ago', 'presso' ),
			'subtitle' => esc_html__( 'Turn on this option to display time ago instead of date', 'presso' ),
			'default' => 0,
		),
	),
) );

Redux::setSection( $vw_opt_name, array(
	'title' => esc_html__( 'Archive', 'presso' ),
	'desc' => '',
	'id' => 'presso-options-archive-page',
	'subsection' => true,
	'fields' => array(
		array(
			'id'=>'archive_page_layout',
			'type' => 'select',
			'title' => esc_html__( 'Page Layout', 'presso' ), 
			'subtitle' => esc_html__( 'Select layout for category page', 'presso' ),
			'options' => array(
				'classic' => esc_html__( 'Classic', 'presso' ),
				'large' => esc_html__( 'Large Featured Post Area', 'presso' ),
			),
			'default' => 'classic',
		),

		array(
			'id'=>'archive_loop_layout',
			'type' => 'select',
			'title' => esc_html__( 'Layout', 'presso' ), 
			'subtitle' => esc_html__( 'Select layout for posts in the archive page', 'presso' ),
			'options' => $vw_loop_layout_options,
			'default' => 'block-a-2',
		),

		array(
			'id'=>'archive_sidebar_position',
			'type' => 'select',
			'title' => esc_html__( 'Sidebar Position', 'presso' ), 
			'subtitle' => esc_html__( 'Select sidebar position for category page', 'presso' ),
			'options' => $vw_sidebar_position_options,
			'default' => 'right',
		),

		array(
			'id'=>'archive_sidebar',
			'type' => 'select',
			'title' => esc_html__( 'Sidebar', 'presso' ), 
			'subtitle' => esc_html__( 'Select default sidebar', 'presso' ),
			'data' => 'sidebar',
			'default' => 'blog-sidebar',
		),

		array(
			'id' => 'presso-options-archive-slider',
			'type' => 'section',
			'title' => esc_html__( 'Featured Posts', 'presso' ),
			'subtitle' => esc_html__( 'This section will show a posts over the archive post listing', 'presso' ),
			'indent' => true,
		),

		array(
			'id'=>'archive_featured_posts_layout',
			'type' => 'select',
			'title' => esc_html__( 'Layout', 'presso' ), 
			'subtitle' => esc_html__( 'Select a layout for featured posts listing', 'presso' ),
			'options' => array(
				'none' => esc_html__( 'Hidden', 'presso' ),
				'slider-xlarge' => esc_html__( 'Slider', 'presso' ),
				'slider-multi-1' => esc_html__( '3 Posts per slide', 'presso' ),
				'slider-multi-2' => esc_html__( '4 Posts per slide', 'presso' ),
				'slider-multi-3' => esc_html__( '5 Posts per slide', 'presso' ),
			),
			'default' => 'slider-xlarge',
		),

		array(
			'id'=>'archive_featured_posts_source',
			'type' => 'select',
			'title' => esc_html__( 'Post Source', 'presso' ), 
			'subtitle' => esc_html__( 'Choose a post source to fetch a featured posts from', 'presso' ),
			'options' => array(
				'featured' => esc_html__( 'Featured Posts', 'presso' ),
				'random' => esc_html__( 'Random', 'presso' ),
			),
			'default' => 'featured',
		),

		array(
			'id' => 'archive_featured_posts_count',
			'type' => 'text',
			'title' => esc_html__( 'Number of Slide', 'presso' ), 
			'subtitle' => esc_html__( 'Enter a number of slide to be displayed in featured area', 'presso' ),
			'validate' => 'numeric',
			'default' => 3,
		),

	),
) );

Redux::setSection( $vw_opt_name, array(
	'title' => esc_html__( 'Search Page', 'presso' ),
	'desc' => '',
	'id' => 'presso-options-search-page',
	'subsection' => true,
	'fields' => array(
		array(
			'id'=>'search_loop_layout',
			'type' => 'select',
			'title' => esc_html__( 'Layout', 'presso' ), 
			'subtitle' => esc_html__( 'Select layout for search page', 'presso' ),
			'options' => $vw_loop_layout_options,
			'default' => 'block-a-2',
		),

		array(
			'id'=>'search_sidebar_position',
			'type' => 'select',
			'title' => esc_html__( 'Sidebar Position', 'presso' ), 
			'subtitle' => esc_html__( 'Select sidebar position for search page', 'presso' ),
			'options' => $vw_sidebar_position_options,
			'default' => 'right',
		),

		array(
			'id'=>'search_sidebar',
			'type' => 'select',
			'title' => esc_html__( 'Sidebar', 'presso' ), 
			'subtitle' => esc_html__( 'Select default sidebar', 'presso' ),
			'data' => 'sidebar',
			'default' => 'blog-sidebar',
		),
	),
) );

Redux::setSection( $vw_opt_name, array(
	'title' => esc_html__( 'Breaking News', 'presso' ),
	'desc' => '',
	'id' => 'presso-options-breaking-news',
	'subsection' => true,
	'fields' => array(
		array(
			'id'=>'breaking_news_loop_layout',
			'type' => 'select',
			'title' => esc_html__( 'Breaking News Layout', 'presso' ), 
			'subtitle' => esc_html__( 'Select layout for breaking news area', 'presso' ),
			'options' => array(
				'none' => esc_html__( 'Disabled', 'presso' ),
				'carousel-2' => esc_html__( '4-posts carousel', 'presso' ),
				'carousel-3' => esc_html__( '7-posts carousel', 'presso' ),
			),
			'default' => 'carousel-2',
		),

		array(
			'id' => 'breaking_news_count',
			'type' => 'text',
			'title' => esc_html__( 'Number of Posts', 'presso' ), 
			'subtitle' => esc_html__( 'Enter a number of posts to be displayed in breaking news', 'presso' ),
			'validate' => 'numeric',
			'default' => 8,
		),

		array(
			'id'=>'breaking_news_display',
			'type' => 'checkbox',
			'title' => esc_html__( 'Breaking News Displays', 'presso' ), 
			'subtitle' => esc_html__( 'Select a page to show breaking news bar', 'presso' ),
			'options' => array(
				'home' => esc_html__( 'Home', 'presso' ),
				'blog' => esc_html__( 'Blog index page', 'presso' ),
				'archive' => esc_html__( 'Archive page', 'presso' ),
				'post' => esc_html__( 'Singe post page', 'presso' ),
				'page' => esc_html__( 'Pages', 'presso' ),
				'shop' => esc_html__( 'Shop', 'presso' ),
				'bbpress' => esc_html__( 'bbPress Pages', 'presso' ),
				'any' => esc_html__( 'Any other pages', 'presso' ),
			),
			'default' => array(
				'home' => '1',
				'blog' => '1',
				'archive' => '1',
				'post' => '1',
				'page' => '0',
				'shop' => '0',
				'bbpress' => '0',
				'any' => '1',
			),
		),

		array(
			'id'=>'breaking_news_source',
			'type' => 'select',
			'title' => esc_html__( 'Breaking News Source', 'presso' ), 
			'subtitle' => esc_html__( 'Select a source of breaking news', 'presso' ),
			'options' => array(
				'random' => esc_html__( 'Random', 'presso' ),
				'featured' => esc_html__( 'Latest Featured Posts', 'presso' ),
			),
			'default' => 'random',
		),
	),
) );

Redux::setSection( $vw_opt_name, array(
	'title' => esc_html__( 'Post Views', 'presso' ),
	'desc' => 'Please install <a href="https://wordpress.org/plugins/post-views-counter/" target="_blank">Post Views Counter plugin</a> to enable post views function',
	'id' => 'presso-options-post-views',
	'subsection' => true,
	'fields' => array(
		array(
			'id' => 'post_views_forgery',
			'type' => 'text',
			'title' => esc_html__( 'Post Views Fogery', 'presso' ), 
			'subtitle' => esc_html__( 'Enter a number to be added into post views', 'presso' ),
			'validate' => 'numeric',
			'default' => 0,
		),
	),
) );



/**
Single Post
 */

Redux::setSection( $vw_opt_name, array(
	'title' => esc_html__( 'Single Post', 'presso' ),
	'desc' => esc_html__( 'An options for single post page', 'presso' ),
	'id' => 'presso-options-single',
	'icon' => 'el el-edit',
	'fields' => array(

		array(
			'id'=>'post_sidebar_position',
			'type' => 'select',
			'title' => esc_html__( 'Default Post Sidebar Position', 'presso' ), 
			'subtitle' => esc_html__( 'Select default sidebar position for post', 'presso' ),
			'options' => $vw_sidebar_position_options,
			'default' => 'right',
		),

		array(
			'id'=>'post_sidebar',
			'type' => 'select',
			'title' => esc_html__( 'Default Sidebar', 'presso' ), 
			'subtitle' => esc_html__( 'Select default sidebar', 'presso' ),
			'data' => 'sidebar',
			'default' => 'blog-sidebar',
		),
	),
) );


Redux::setSection( $vw_opt_name, array(
	'title' => esc_html__( 'Post Footer', 'presso' ),
	'desc' => '',
	'id' => 'presso-options-post-footer',
	'subsection' => true,
	'fields' => array(
		array(
			'id' => 'post_footer_sections',
			'type' => 'sorter',
			'title' => esc_html__( 'Post Footer Sections', 'presso' ),
			'subtitle' => esc_html__( 'Organize how you want the order of additional sections to appear on the footer of post', 'presso' ),
			'options' => array(
				'enabled' => array(
					'post-navigation' => esc_html__( 'Next/Previous Post', 'presso' ),
					'about-author' => esc_html__( 'About Author', 'presso' ),
					'related-posts' => esc_html__( 'Related Posts', 'presso' ),
					'suggested-posts' => esc_html__( 'Suggested Posts', 'presso' ),
					'comments' => esc_html__( 'Comments', 'presso' ),
				),
				'disabled' => array(
					'custom-1' => esc_html__( 'Custom Section 1', 'presso' ),
					'custom-2' => esc_html__( 'Custom Section 2', 'presso' ),
				)
			),
		),

		array(
			'id'=>'post_footer_section_custom_1',
			'type' => 'editor', 
			'title' => esc_html__( 'Custom Section 1', 'presso' ),
			'subtitle' => esc_html__( 'Enter the content', 'presso' ),
		),

		array(
			'id'=>'post_footer_section_custom_2',
			'type' => 'editor', 
			'title' => esc_html__( 'Custom Section 2', 'presso' ),
			'subtitle' => esc_html__( 'Enter the content', 'presso' ),
		),

		array(
			'id' => 'presso-options-single-related-posts',
			'type' => 'section',
			'title' => esc_html__( 'Related Posts', 'presso' ),
			'subtitle' => esc_html__( 'This section will show a related posts based on the same tag and category', 'presso' ),
			'indent' => true,
		),

		array(
			'id'=>'related_post_layout',
			'type' => 'select',
			'title' => esc_html__( 'Layout', 'presso' ), 
			'subtitle' => esc_html__( 'Select layout for related posts', 'presso' ),
			'options' => $vw_loop_layout_options,
			'default' => 'block-g-2',
		),

		array(
			'id'=>'related_post_count',
			'type' => 'spinner',
			'title' => esc_html__( 'Number of posts', 'presso' ), 
			'subtitle' => esc_html__( 'The number of posts to be displayed', 'presso' ),
			'min' => '1',
			'max' => '20',
			'default' => '4',
		),

		array(
			'id' => 'presso-options-single-suggested-posts',
			'type' => 'section',
			'title' => esc_html__( 'Suggested Posts', 'presso' ),
			'indent' => true,
		),

		array(
			'id'=>'suggested_post_layout',
			'type' => 'select',
			'title' => esc_html__( 'Layout', 'presso' ), 
			'subtitle' => esc_html__( 'Select layout for suggested posts', 'presso' ),
			'options' => $vw_loop_layout_options,
			'default' => 'block-g-3',
		),

		array(
			'id'=>'suggested_post_count',
			'type' => 'spinner',
			'title' => esc_html__( 'Number of posts', 'presso' ), 
			'subtitle' => esc_html__( 'The number of posts to be displayed', 'presso' ),
			'min' => '1',
			'max' => '20',
			'default' => '6',
		),

		array(
			'id'=>'suggested_post_order',
			'type' => 'select',
			'title' => esc_html__( 'Post Source', 'presso' ), 
			'options' => array(
				'random' => esc_html__( 'Random', 'presso' ),
				'featured' => esc_html__( 'Latest featured posts', 'presso' ),
				'latest_gallery' => esc_html__( 'Latest gallery posts', 'presso' ),
				'latest_video' => esc_html__( 'Latest video posts', 'presso' ),
				'latest_audio' => esc_html__( 'Latest audio posts', 'presso' ),
				'latest_reviews' => esc_html__( 'Latest reviews', 'presso' ),
				'most_review_score' => esc_html__( 'Most Review Score', 'presso' ),
			),
			'default' => 'random',
		),
	),
) );





/**
Gallery Slider
 */

Redux::setSection( $vw_opt_name, array(
	'title' => esc_html__( 'Gallery Slider', 'presso' ),
	'desc' => esc_html__( 'These are the options for the image gallery slider that is displayed in the blog entry, page composer', 'presso' ),
	'id' => 'presso-options-gallery-slider',
	'icon' => 'el el-picture',
	'fields' => array(
		array(
			'id' => 'slider_slide_duration',
			'type' => 'text',
			'title' => esc_html__( 'Slideshow Duration', 'presso' ), 
			'subtitle' => esc_html__( 'The time for showing slide, in milliseconds', 'presso' ),
			'validate' => 'numeric',
			'default' => 4000,
		),
		array(
			'id' => 'slider_transition_speed',
			'type' => 'text',
			'title' => esc_html__( 'Transition Speed', 'presso' ), 
			'subtitle' => esc_html__( 'The time for transition, in milliseconds', 'presso' ),
			'validate' => 'numeric',
			'default' => 300,
		),
	),
) );




/**
Font Icons
 */

Redux::setSection( $vw_opt_name, array(
	'title' => esc_html__( 'Font Icons', 'presso' ),
	'desc' => wp_kses_post( sprintf( __( 'You can choose additional icon fonts. The default font icons that are already in use are <a href="http://entypo.com">Entypo</a> (Icon listing <a href="%1$s/font-icons/entypo/demo.html">here</a>) and <a href="http://zocial.smcllns.com">Zocial</a> (Icon listing <a href="%1$s/font-icons/social-icons/demo.html">here</a>).', 'presso' ), esc_url( get_template_directory_uri() ) ) ),
	'id' => 'presso-options-font-icons',
	'icon' => 'el el-puzzle',
	'fields' => array(
		array(
			'id' => 'enable_icon_iconic',
			'type' => 'switch',
			'title' => esc_html__( 'Include Iconic Icons', 'presso' ),
			'desc' => wp_kses_post( sprintf( __( 'by <a href="http://somerandomdude.com/work/iconic">P.J. Onori</a>, The icon listing is <a href="%1$s/font-icons/iconic/demo.html">here</a>', 'presso' ), esc_url( get_template_directory_uri() ) ) ),
			'default' => 0
		),
		array(
			'id' => 'enable_icon_elusive',
			'type' => 'switch',
			'title' => esc_html__( 'Include Elusive Icons', 'presso' ),
			'desc' => wp_kses_post( sprintf( __( 'by <a href="http://aristeides.com">Aristeides Stathopoulos</a>, The icon listing is <a href="%1$s/font-icons/elusive/demo.html">here</a>', 'presso' ), esc_url( get_template_directory_uri() ) ) ),
			'default' => 0
		),
		array(
			'id' => 'enable_icon_awesome',
			'type' => 'switch',
			'title' => esc_html__( 'Include Font Awesome Icons', 'presso' ),
			'desc' => wp_kses_post( sprintf( __( 'by <a href="http://fontawesome.io">Dav Gandy</a>, The icon listing is <a href="%1$s/font-icons/awesome/demo.html">here</a>', 'presso' ), esc_url( get_template_directory_uri() ) ) ),
			'default' => 0
		),
		/*array(
			'id' => 'enable_icon_entypo',
			'type' => 'switch',
			'title' => esc_html__( 'Include Entypo Icons', 'presso' ),
			'desc' => 'by <a href="http://entypo.com">Entypo.com</a>, The icon listing is <a href="'.get_template_directory_uri().'/components/font-icons/entypo/demo.html">here</a>',
			'default' => 1
		),*/
		array(
			'id' => 'enable_icon_typicons',
			'type' => 'switch',
			'title' => esc_html__( 'Include Typicons Icons', 'presso' ),
			'desc' => wp_kses_post( sprintf( __( 'by <a href="http://typicons.com">Stephen Hutchings</a>, The icon listing is <a href="%1$s/font-icons/typicons/demo.html">here</a>', 'presso' ), esc_url( get_template_directory_uri() ) ) ),
			'default' => 0,
		),
	),
) );



/**
bbPress
 */

Redux::setSection( $vw_opt_name, array(
	'title'      => 'bbPress',
	'desc'       => wp_kses_post( __( 'These are options for bbPress. Please install the <a href="https://wordpress.org/plugins/bbpress/" target="_blank">bbPress plugin</a> before using these options.', 'presso' ) ),
	'id'         => 'vw-options-bbpress',
	'icon'       => 'el el-list',
	'fields'     => array(
		array(
			'id'=>'bbpress_sidebar_position',
			'type' => 'select',
			'title' => esc_html__( 'Sidebar Position', 'presso' ), 
			'subtitle' => esc_html__( 'Select sidebar position for bbPress pages', 'presso' ),
			'options' => $vw_sidebar_position_options,
			'default' => 'right',
		),

		array(
			'id'=>'bbpress_sidebar',
			'type' => 'select',
			'title' => esc_html__( 'Sidebar', 'presso' ), 
			'subtitle' => esc_html__( 'Select default sidebar', 'presso' ),
			'data' => 'sidebar',
			'default' => 'blog-sidebar',
		),
	),
) );



/**
WooCommerce
 */

Redux::setSection( $vw_opt_name, array(
	'title'      => 'WooCommerce',
	'desc'       => wp_kses_post( __( 'These are options for WooCommerce. Please install the <a href="https://wordpress.org/plugins/woocommerce/" target="_blank">WooCommerce plugin</a> before using these options.', 'presso' ) ),
	'id'         => 'vw-options-woocommerce',
	'icon'       => 'el el-shopping-cart',
	'fields'     => array(
		array(
			'id'		=> 'woocommerce_products_per_page',
			'type'		=> 'text',
			'title'		=> esc_html__( 'Products Per Page', 'presso' ),
			'subtitle'	=> esc_html__( 'Enter the number of products per page.', 'presso' ),
			'validate'	=> 'numeric',
			'default'	=> 9,
		),
	),
) );





/**
Custom CSS
 */

Redux::setSection( $vw_opt_name, array(
	'title' => esc_html__( 'Custom CSS', 'presso' ),
	'desc' => '',
	'id' => 'presso-options-custom-css',
	'icon' => 'el el-css',
	'fields' => array(
		array(
			'id'=>'custom_css',
			'type' => 'ace_editor', 
			'theme' => 'monokai',
			'mode' => 'css',
			'title' => esc_html__( 'Custom CSS', 'presso' ),
			'subtitle' => esc_html__( 'Paste your CSS code here', 'presso' ),
		),
	),
) );

do_action( 'presso_action_init_theme_options', $vw_opt_name );





/* -----------------------------------------------------------------------------
 * Actions
 * -------------------------------------------------------------------------- */
add_action( 'redux/options/'.$vw_opt_name.'/saved', 'presso_options_saved' );
if ( ! function_exists( 'presso_options_saved' ) ) {
	function presso_options_saved() {
		return;
	}
}