<?php
$score_style = esc_html( get_post_meta( get_the_id(), 'vw_review_score_style', true ) );
$review_position = esc_html( get_post_meta( get_the_id(), 'vw_review_position', true ) );
$review_pros = get_post_meta( get_the_id(), 'vw_review_pros', true );
$review_cons = get_post_meta( get_the_id(), 'vw_review_cons', true );
$scores = get_field( 'vw_review_scores', get_the_id() );

$average_score = 0;
foreach( $scores as $score ) {
	$average_score += $score['score'];
}

if ( $average_score > 0 ) {
	$average_score /= count( $scores );
}
?>
<div class="vw-review clearfix <?php echo esc_attr( sprintf( 'vw-review--%s vw-review--%s', $review_position, $score_style ) ) ?>" itemscope itemtype="https://schema.org/Review">
	<meta itemprop="itemReviewed" content="<?php echo esc_attr( get_the_title() ); ?>">
	<meta itemprop="author" content="<?php echo esc_attr( get_the_author() ); ?>">
	<meta itemprop="datePublished" content="<?php echo esc_attr( get_the_date( 'Y-m-d' ) ); ?>">

	<h3 class="vw-review__title"><span><?php esc_html_e( 'The Breakdown', 'presso' ); ?></span></h3>

	<div class="vw-review__summary clearfix">
		<?php $review_summary = get_post_meta( get_the_id(), 'vw_review_summary', true ); ?>

		<?php if ( 'percentage' == $score_style ) : ?>
			<?php $display_score = intval( $average_score ); ?>
			<div class="vw-review__total vw-review__total--percentage" itemprop="reviewRating" itemscope itemtype="https://schema.org/Rating">
				<input type="text" value="<?php echo esc_attr( $display_score ); ?>" class="vw-review__dial">
				
				<meta itemprop="worstRating" content="0">
				<meta itemprop="bestRating" content="100">
				<meta itemprop="ratingValue" content="<?php echo esc_attr( $display_score ); ?>">
			</div>

		<?php elseif ( 'points' == $score_style ) : ?>
			<?php $display_score = number_format( $average_score / 10.0, 1 ); ?>
			<div class="vw-review__total vw-review__total--point" itemprop="reviewRating" itemscope itemtype="https://schema.org/Rating">
				<input type="text" value="<?php echo esc_attr( $display_score ); ?>" class="vw-review__dial">

				<meta itemprop="worstRating" content="0">
				<meta itemprop="bestRating" content="10">
				<meta itemprop="ratingValue" content="<?php echo esc_attr( $display_score ); ?>">
			</div>

		<?php elseif ( 'star' == $score_style ) : ?>
			<?php $display_score = number_format( $average_score / 20.0, 1 ); ?>
			<div class="vw-review__total vw-review__total--star" itemprop="reviewRating" itemscope itemtype="https://schema.org/Rating">
				<span class="hidden"><?php echo esc_html( $display_score ); ?></span>

				<meta itemprop="worstRating" content="0">
				<meta itemprop="bestRating" content="5">
				<meta itemprop="ratingValue" content="<?php echo esc_attr( $display_score ); ?>">

				<?php presso_the_review_stars( $average_score, 100, 'large' ); ?>
			</div>

		<?php endif; ?>

		<div class="vw-review__review-summary" itemprop="reviewBody"><?php echo wp_kses_post( $review_summary ); ?></div>
		
	</div>

	<div class="vw-review__items">
		<?php
		foreach( $scores as $score ) :
			$label = $score[ 'label' ];
			$score = $score[ 'score' ];

			if ( empty( $score ) ) break;

			$score_percent = floatval( $score ) . '%';
		?>
		<div class="vw-review__item clearfix">
			<div class="vw-review__item-title">

				<span><?php echo esc_html( $label ) ?></span>

				<?php if ( 'percentage' == $score_style ) : ?>
					<span class="vw-review__item-title-separator">&ndash;</span>
					<span class="vw-review__item-title-score"><?php echo esc_html( $score_percent ); ?></span>

				<?php elseif ( 'points' == $score_style ) : ?>
					<span class="vw-review__item-title-separator">&ndash;</span>
					<span class="vw-review__item-title-score"><?php echo number_format( $score / 10.0, 1 ); ?></span>
				
				<?php endif; ?>

			</div>

			<?php if ( 'percentage' == $score_style || 'points' == $score_style ) : ?>
				<div class="vw-review__item-score"><div class="vw-review__item-score-bar" style="width: <?php echo esc_attr( $score_percent ); ?>;"></div></div>

			<?php elseif ( 'star' == $score_style ) : ?>
				<div class="vw-review__item-score"><?php presso_the_review_stars( $score, 100 ); ?></div>

			<?php endif; ?>

		</div>
		<?php endforeach; ?>
	</div>

	<?php if ( ! empty( $review_pros ) && ! empty( $review_cons ) ) : ?>

	<div class="vw-review__pros-cons">

		<div class="vw-review__pros">
			<h5 class="vw-review__pros-title"><?php esc_html_e( 'Pros', 'presso' ) ?></h5>
			<div class="vw-review__pros-summary"><?php echo wp_kses_post( $review_pros ); ?></div>
		</div>

		<div class="vw-review__cons">
			<h5 class="vw-review__cons-title"><?php esc_html_e( 'Cons', 'presso' ) ?></h5>
			<div class="vw-review__cons-summary"><?php echo wp_kses_post( $review_cons ); ?></div>
		</div>

	</div>

	<?php endif; ?>
</div>